@@ -17,13 +17,17 @@ use cortex_m_rt::entry;
 use stm32_hal2::{
     clocks::Clocks,
     dma::{self, Dma, DmaChannel, DmaInterrupt, DmaWriteBuf},
-    gpio::{Pin, PinMode, Port},
+    gpio::{self, Pin, PinMode, Port},
     low_power,
     pac::{self, interrupt},
     prelude::*,
     spi::{self, BaudRate, Spi, SpiConfig, SpiMode},
 };
 
+// Byte 0 is for the address we pass in the `write` transfer; relevant data is in the rest of
+// the values.
+static mut SPI_READ_BUF: [u8; 4] = [0; 4];
+
 make_globals!((SPI, Spi<SPI1>), (DMA, Dma<DMA1>),);
 
 #[entry]
@@ -42,13 +46,14 @@ fn main() -> ! {
     let _miso = Pin::new(Port::A, 6, PinMode::Alt(5));
     let _mosi = Pin::new(Port::A, 7, PinMode::Alt(5));
 
-    let cs = Pin::new(Port::A, 1, PinMode::Output);
+    let mut cs = Pin::new(Port::A, 1, PinMode::Output);
 
     let spi_cfg = SpiConfig {
         mode: SpiMode::mode1(),
         // `SpiConfig::default` is mode 0, full duplex, with software CS.
         ..Default::default()
     };
+
     // Alternatively, we can configure Mode py polarity and phase:
     // mode: SpiMode {
     //     polarity: SpiPolarity::IdleLow,
@@ -65,28 +70,33 @@ fn main() -> ! {
     // Set up DMA, for nonblocking (generally faster) conversion transfers:
     let mut dma = Dma::new(&mut dp.DMA1, &dp.RCC);
 
-    // We read 3 bytes from the `0x9f` register.
-    let mut write_buf = [0x80, 100];
-    let mut read_buf = [0x9f, 0, 0, 0];
-
     // todo: Write example.
 
     cs.set_low();
 
     unsafe {
-        spi.write_dma(&read_buf, DmaChannel::C3, Default::default(), &mut dma);
-        spi.read_dma(&mut read_buf, DmaChannel::C2, Default::default(), &mut dma);
+        // Write to SPI, using DMA.
+        // spi.write_dma(&write_buf, DmaChannel::C1, Default::default(), &mut dma);
+
+        // Read (transfer) from SPI, using DMA.
+        spi.transfer_dma(
+            // Write buffer, starting with the registers we'd like to access, and 0-padded to
+            // read 3 bytes.
+            &[0x69, 0, 0, 0],
+            &mut SPI_READ_BUF,  // Read buf, where the data will go
+            DmaChannel::C1,     // Write channel
+            DmaChannel::C2,     // Read channel
+            Default::Deafult,   // Write channel config
+            Default::default(), // Read channel config
+            &mut dma,
+        );
     }
 
-    while !dma.transfer_is_complete(DmaChannel::C2) {}
-    spi.stop_dma(DmaChannel::C2, &mut dma);
-    spi.stop_dma(DmaChannel::C3, &mut dma);
-
-    cs.set_high();
-
-    defmt::println!("Data: {}", read_buf);
-
     // Alternatively, use the blocking, non-DMA SPI API` (Also supports `embedded-hal` traits):
+
+    // We read 3 bytes from the `0x9f` register.
+    let mut write_buf = [0x80, 100];
+    let mut read_buf = [0x9f, 0, 0, 0];
     spi.write(&write_buf).ok();
     spi.transfer(&mut read_buf).ok();
     defmt::println!("Data: {}", read_buf);
@@ -97,10 +107,10 @@ fn main() -> ! {
         SPI.borrow(cs).replace(Some(spi));
     });
 
-    // Unmask the interrupt line. See the `DMA_CH2` and `DMA_CH3` interrupt handlers below.
+    // Unmask the interrupt line for DMA read complete. See the `DMA_CH3` interrupt handlers below,
+    // where we set CS high, terminal the DMA read, and display the data read.
     unsafe {
         NVIC::unmask(pac::Interrupt::DMA1_CH2);
-        NVIC::unmask(pac::Interrupt::DMA1_CH3);
     }
 
     // Alternatively, we can take readings without DMA. This provides a simpler, memory-safe API,
@@ -111,28 +121,11 @@ fn main() -> ! {
     }
 }
 
-#[interrupt]
-/// This interrupt fires when a DMA transmission is complete
-fn DMA1_CH3() {
-    free(|cs| {
-        access_global!(DMA, dma, cs);
-        access_global!(SPI, spi, cs);
-
-        dma.clear_interrupt(DmaChannel::C3, DmaInterrupt::TransferComplete);
-        spi.stop_dma(DmaChannel::C3, dma);
-
-        unsafe {
-            // Set CS high as required.
-            // (*pac::GPIOB::ptr()).bsrr.write(|w| w.bits(1 << 15));
-        }
-    })
-}
-
 #[interrupt]
 /// This interrupt fires when a DMA read is complete
 fn DMA1_CH2() {
     free(|cs| {
-        defmt::println!("SPI DMA STOPPED");
+        defmt::println!("SPI DMA read complete");
         access_global!(DMA, dma, cs);
         access_global!(SPI, spi, cs);
 
@@ -140,9 +133,12 @@ fn DMA1_CH2() {
         spi.stop_dma(DmaChannel::C2, dma);
 
         unsafe {
-            // Set CS high as required.
-            // (*pac::GPIOB::ptr()).bsrr.write(|w| w.bits(1 << 15));
+            // Ignore byte 0, which is the reg we passed during the write.
+            println!("Data read: {:?}", SPI_READ_BUF);
         }
+
+        // Set CS high.
+        gpio::set_high(Port::A, 1);
     })
 }
 
