@@ -848,8 +848,7 @@ macro_rules! hal {
 
             // todo: fn read_voltage, using vrefint and L4xx-hal style calibration?
 
-            // todo: H7 having issues with adc3 etc. Fix at least for adc1 and 2.
-            #[cfg(not(any(feature = "g0", feature = "f4", feature = "h7", feature = "l5")))]
+            #[cfg(not(any(feature = "g0", feature = "f4", feature = "l5")))]
             /// Take a one shot reading, using DMA. See L44 RM, 16.4.27: "DMA one shot mode".
             /// Note that the `channel` argument is only used on F3 and L4.
             pub unsafe fn read_dma<D>(
@@ -865,11 +864,20 @@ macro_rules! hal {
                 // The software is allowed to write (dmaen and dmacfg) only when ADSTART=0 and JADSTART=0 (which
                 // ensures that no conversion is ongoing)
                 self.stop_conversions();
+
+                #[cfg(not(feature = "h7"))]
                 self.regs.cfgr.modify(|_, w| {
                     w.dmacfg().bit(channel_cfg.circular == dma::Circular::Enabled);
                     w.dmaen().set_bit()
                 });
 
+                #[cfg(feature = "h7")]
+                self.regs.cfgr.modify(|_, w| {
+                    // Note: To use non-DMA after this has been set, need to configure manually.
+                    // ie set back to 0b00.
+                    w.dmngt().bits(if channel_cfg.circular == dma::Circular::Enabled { 0b11 } else { 0b01 })
+                });
+
                 // L44 RM, Table 41. "DMA1 requests for each channel
                 // todo: DMA2 support.
                 #[cfg(any(feature = "f3", feature = "l4"))]
@@ -929,15 +937,15 @@ macro_rules! hal {
                 // • The DMA is stopped.
 
                 #[cfg(feature = "h7")]
-                let len = len as u32;
+                let num_data = len as u32;
                 #[cfg(not(feature = "h7"))]
-                let len = len as u16;
+                let num_data = len as u16;
 
                 dma.cfg_channel(
                     dma_channel,
                     &self.regs.dr as *const _ as u32,
                     ptr as u32,
-                    len,
+                    num_data,
                     dma::Direction::ReadFromPeriph,
                     dma::DataSize::S16,
                     dma::DataSize::S16,
