@@ -80,6 +80,38 @@ pub enum DmaInput {
     Adc3 = 37,
     Adc4 = 38,
     Adc5 = 39,
+    Quadspi = 40,
+    Dac2Ch1 = 41,
+    Tim1Ch1 = 42,
+    Tim1Ch2 = 43,
+    Tim1Ch3 = 44,
+    Tim1Ch4 = 45,
+    TimUp = 46,
+    Tim1Trig = 47,
+    Tim1Com = 48,
+    Tim8Ch1 = 49,
+    Tim8Ch2 = 50,
+    Tim8Ch3 = 51,
+    Tim8Ch4 = 52,
+    Tim8Up = 53,
+    Tim8Trig = 54,
+    Tim8Com = 55,
+    Tim2Ch1 = 56,
+    Tim2Ch2 = 57,
+    Tim2Ch3 = 58,
+    Tim2Ch4 = 59,
+    Tim2Up = 60,
+    Tim3Ch1 = 61,
+    Tim3Ch2 = 62,
+    Tim3Ch3 = 63,
+    Tim3Ch4 = 64,
+    Tim3Up = 65,
+    Tim3Trig = 66,
+    Tim4Ch1 = 67,
+    Tim4Ch2 = 68,
+    Tim4Ch3 = 69,
+    Tim4Ch4 = 70,
+    Tim4Up = 71,
     Sai1A = 108,
     Sai1B = 109,
     // todo: These SAI2 values are bogus; can't find on G4 DMA mux.
@@ -101,32 +133,60 @@ pub enum DmaInput {
 pub enum DmaInput {
     Adc1 = 9,
     Adc2 = 10,
-    DacCh1 = 67,
-    DacCh2 = 68,
-    Tim6Up = 69,
-    Tim7Up = 70,
-    Spi1Rx = 37,
-    Spi1Tx = 38,
-    Spi2Rx = 39,
-    Spi2Tx = 40,
-    Spi3Rx = 61,
-    Spi3Tx = 62,
+    Tim1Ch1 = 11,
+    Tim1Ch2 = 12,
+    Tim1Ch3 = 13,
+    Tim1Ch4 = 14,
+    Tim1Up = 15,
+    Tim1Trig = 16,
+    Tim1Com = 17,
+    Tim2Ch1 = 18,
+    Tim2Ch2 = 19,
+    Tim2Ch3 = 20,
+    Tim2Ch4 = 21,
+    Tim2Up = 22,
+    Tim3Ch1 = 23,
+    Tim3Ch2 = 24,
+    Tim3Ch3 = 25,
+    Tim3Ch4 = 26,
+    Tim3Up = 27,
+    Tim3Trig = 28,
+    Tim4Ch1 = 29,
+    Tim4Ch2 = 30,
+    Tim4Ch3 = 31,
+    Tim4Up = 32,
     I2c1Rx = 33,
     I2c1Tx = 34,
     I2c2Rx = 35,
     I2c2Tx = 36,
-    I2c3Rx = 73,
-    I2c3Tx = 74,
+    Spi1Rx = 37,
+    Spi1Tx = 38,
+    Spi2Rx = 39,
+    Spi2Tx = 40,
     Usart1Rx = 41,
     Usart1Tx = 42,
     Usart2Rx = 43,
     Usart2Tx = 44,
     Usart3Rx = 45,
     Usart3Tx = 46,
+    Tim5Ch1 = 55,
+    Tim5Ch2 = 56,
+    Tim5Ch3 = 57,
+    Tim5Ch4 = 58,
+    Tim5Up = 59,
+    Tim5Trig = 60,
+    Spi3Rx = 61,
+    Spi3Tx = 62,
     Uart4Rx = 63,
     Uart4Tx = 64,
     Uart5Rx = 65,
     Uart5Tx = 66,
+    DacCh1 = 67,
+    DacCh2 = 68,
+    Tim6Up = 69,
+    Tim7Up = 70,
+    I2c3Rx = 73,
+    I2c3Tx = 74,
     Sai1A = 87,
     Sai1B = 88,
     Sai2A = 89,
@@ -352,6 +412,7 @@ pub enum DmaInterrupt {
 /// Reduce DRY over channels when configuring a channel's CCR.
 /// We must use a macro here, since match arms balk at the incompatible
 /// types of `CCR1`, `CCR2` etc.
+#[cfg(not(feature = "h7"))]
 macro_rules! set_ccr {
     ($ccr:expr, $priority:expr, $direction:expr, $circular:expr, $periph_incr:expr, $mem_incr:expr, $periph_size:expr, $mem_size:expr) => {
         // "The register fields/bits MEM2MEM, PL[1:0], MSIZE[1:0], PSIZE[1:0], MINC, PINC, and DIR
@@ -387,6 +448,7 @@ macro_rules! set_ccr {
 }
 
 /// Reduce DRY over channels when configuring a channel's interrupts.
+#[cfg(not(feature = "h7"))]
 macro_rules! enable_interrupt {
     ($ccr:expr, $interrupt_type:expr) => {
         let originally_enabled = $ccr.read().en().bit_is_set();
@@ -1491,19 +1553,22 @@ pub fn mux(channel: DmaChannel, input: DmaInput, mux: &mut DMAMUX) {
     unsafe {
         #[cfg(not(any(feature = "g070", feature = "g071", feature = "g081", feature = "h7")))]
         match channel {
-            DmaChannel::C1 => mux.c1cr.modify(|_, w| w.dmareq_id().bits(input as u8)),
-            DmaChannel::C2 => mux.c2cr.modify(|_, w| w.dmareq_id().bits(input as u8)),
-            DmaChannel::C3 => mux.c3cr.modify(|_, w| w.dmareq_id().bits(input as u8)),
-            DmaChannel::C4 => mux.c4cr.modify(|_, w| w.dmareq_id().bits(input as u8)),
-            DmaChannel::C5 => mux.c5cr.modify(|_, w| w.dmareq_id().bits(input as u8)),
+            // Note the offset by 1, due to mismatch in DMA channels starting at 1, and DMAMUX
+            // channels starting at 0. Ops tested this is correct on G4.
+            DmaChannel::C1 => mux.c0cr.modify(|_, w| w.dmareq_id().bits(input as u8)),
+            DmaChannel::C2 => mux.c1cr.modify(|_, w| w.dmareq_id().bits(input as u8)),
+            DmaChannel::C3 => mux.c2cr.modify(|_, w| w.dmareq_id().bits(input as u8)),
+            DmaChannel::C4 => mux.c3cr.modify(|_, w| w.dmareq_id().bits(input as u8)),
+            DmaChannel::C5 => mux.c4cr.modify(|_, w| w.dmareq_id().bits(input as u8)),
             #[cfg(not(feature = "g0"))]
-            DmaChannel::C6 => mux.c6cr.modify(|_, w| w.dmareq_id().bits(input as u8)),
+            DmaChannel::C6 => mux.c5cr.modify(|_, w| w.dmareq_id().bits(input as u8)),
             #[cfg(not(feature = "g0"))]
-            DmaChannel::C7 => mux.c7cr.modify(|_, w| w.dmareq_id().bits(input as u8)),
+            DmaChannel::C7 => mux.c6cr.modify(|_, w| w.dmareq_id().bits(input as u8)),
             #[cfg(any(feature = "l5", feature = "g4"))]
-            DmaChannel::C8 => mux.c8cr.modify(|_, w| w.dmareq_id().bits(input as u8)),
+            DmaChannel::C8 => mux.c7cr.modify(|_, w| w.dmareq_id().bits(input as u8)),
         }
         #[cfg(any(feature = "g070", feature = "g071", feature = "g081"))]
+        // todo: Do we also need to offset by one on G4?
         match channel {
             DmaChannel::C1 => mux
                 .dmamux_c1cr
@@ -1532,3 +1597,24 @@ pub fn mux(channel: DmaChannel, input: DmaInput, mux: &mut DMAMUX) {
 pub fn mux2(channel: DmaChannel, input: DmaInput2, mux: &mut DMAMUX2) {
     mux.ccr[channel as usize].modify(|_, w| unsafe { w.dmareq_id().bits(input as u8) });
 }
+
+// todo: Enable this for other MCUs as requried
+/// Enable the DMA mux RCC clock. Applicable to some variants, but no others. (H7 and G0 don't use it,
+/// for example)
+#[cfg(any(feature = "g4", feature = "wb"))]
+pub fn enable_mux1() {
+    free(|_| {
+        let rcc = unsafe { &(*RCC::ptr()) };
+
+        cfg_if! {
+            if #[cfg(feature = "g4")] {
+                // Note inconsistency between `dmamux` and `dmamux`; can't use macro here.
+                rcc.ahb1enr.modify(|_, w| w.dmamuxen().set_bit());
+                rcc.ahb1rstr.modify(|_, w| w.dmamux1rst().set_bit());
+                rcc.ahb1rstr.modify(|_, w| w.dmamux1rst().clear_bit());
+            } else {
+                rcc_en_reset!(ahb1, dmamux, rcc);
+            }
+        }
+    });
+}
