@@ -13,9 +13,12 @@ use embedded_hal::blocking::i2c::{Read, Write, WriteRead};
 use crate::{
     clocks::Clocks,
     pac::{self, RCC},
-    util::{DmaPeriph, RccPeriph},
+    util::RccPeriph,
 };
 
+#[cfg(any(feature = "f3", feature = "l4"))]
+use crate::util::DmaPeriph;
+
 #[cfg(any(feature = "g0"))]
 use crate::pac::dma as dma_p;
 #[cfg(any(
@@ -134,6 +137,7 @@ pub enum NoiseFilter {
 }
 
 /// Initial configuration data for the I2C peripheral.
+#[derive(Clone)]
 pub struct I2cConfig {
     /// Select master or slave mode. Defaults to Master.
     pub mode: I2cMode,
@@ -175,7 +179,8 @@ pub struct I2c<R> {
 
 impl<R> I2c<R>
 where
-    R: Deref<Target = pac::i2c1::RegisterBlock> + DmaPeriph + RccPeriph,
+    // R: Deref<Target = pac::i2c1::RegisterBlock> + DmaPeriph + RccPeriph,
+    R: Deref<Target = pac::i2c1::RegisterBlock> + RccPeriph,
 {
     /// Initialize a I2C peripheral, including configuration register writes, and enabling and resetting
     /// its RCC peripheral clock. `freq` is in Hz.
@@ -594,15 +599,15 @@ where
         // Note: If DMA is used for transmission, the TXIE bit does not need to be enabled
 
         #[cfg(feature = "h7")]
-        let len = len as u32;
+        let num_data = len as u32;
         #[cfg(not(feature = "h7"))]
-        let len = len as u16;
+        let num_data = len as u16;
 
         dma.cfg_channel(
             channel,
             &self.regs.txdr as *const _ as u32,
             ptr as u32,
-            len,
+            num_data,
             dma::Direction::ReadFromMem,
             dma::DataSize::S8,
             dma::DataSize::S8,
@@ -677,7 +682,7 @@ where
 // #[cfg_attr(docsrs, doc(cfg(feature = "embedded-hal")))]
 impl<R> Write for I2c<R>
 where
-    R: Deref<Target = pac::i2c1::RegisterBlock> + DmaPeriph + RccPeriph,
+    R: Deref<Target = pac::i2c1::RegisterBlock> + RccPeriph,
 {
     type Error = Error;
 
@@ -690,7 +695,7 @@ where
 // #[cfg_attr(docsrs, doc(cfg(feature = "embedded-hal")))]
 impl<R> Read for I2c<R>
 where
-    R: Deref<Target = pac::i2c1::RegisterBlock> + DmaPeriph + RccPeriph,
+    R: Deref<Target = pac::i2c1::RegisterBlock> + RccPeriph,
 {
     type Error = Error;
 
@@ -703,7 +708,7 @@ where
 // #[cfg_attr(docsrs, doc(cfg(feature = "embedded-hal")))]
 impl<R> WriteRead for I2c<R>
 where
-    R: Deref<Target = pac::i2c1::RegisterBlock> + DmaPeriph + RccPeriph,
+    R: Deref<Target = pac::i2c1::RegisterBlock> + RccPeriph,
 {
     type Error = Error;
 
