@@ -363,7 +363,7 @@ pub mod adc;
 // H7 suppords fd and can_ccu. (What's that?)
 // WB and WL?
 #[cfg(all(
-    feature = "can",
+    feature = "bx_can",
     not(any(feature = "f301", feature = "f401", feature = "f410", feature = "f411"))
 ))]
 pub mod can;
@@ -597,7 +597,7 @@ pub fn debug_workaround() {
         }
     });
 
-    free(|cs| {
+    free(|_| {
         let rcc = unsafe { &(*pac::RCC::ptr()) };
 
         // todo Some MCUs may need the dbgmcu lines, but not DMA enabled.
